src/node/i-node.h
changeset 728 95c426b1cb60
parent 710 2a9c061219a7
--- a/src/node/i-node.h	Fri May 25 21:53:24 2007 +0200
+++ b/src/node/i-node.h	Mon Jun 04 16:17:01 2007 +0200
@@ -19,7 +19,7 @@
 // Author: George F. Riley<riley@ece.gatech.edu>
 //
 
 // Define the basic INode object for ns3.
 // George F. Riley, Georgia Tech, Fall 2006
 
 #ifndef I_NODE_H
@@ -37,35 +37,35 @@
 class Application;
 
 /**
- * \brief A network INode.
+ * \brief A network Node.
  *
  * This class holds together:
  *   - a list of NetDevice objects which represent the network interfaces
- *     of this node which are connected to other INode instances through
+ *     of this node which are connected to other Node instances through
  *     Channel instances.
  *   - a list of Application objects which represent the userspace
  *     traffic generation applications which interact with the INode
  *     through the Socket API.
  *   - a node Id: a unique per-node identifier.
  *   - a system Id: a unique Id used for parallel simulations.
  *   - a trace resolver which can be used to connect user trace sinks
  *     to the node's trace sources.
  *
- * Every INode created is added to the NodeList automatically.
+ * Every Node created is added to the NodeList automatically.
  */
-class INode : public Object
+class Node : public Object
 {
 public:
   static const InterfaceId iid;
 
-  virtual ~INode();
+  virtual ~Node();
 
   /**
    * \param context the trace context for the TraceResolver to create
    * \returns a newly-created TraceResolver. The caller takes
    *          ownership of the returned pointer.
    *
    * Request the INode to create a trace resolver. This method
    * could be used directly by a user who needs access to very low-level
    * trace configuration.
    */
@@ -74,7 +74,7 @@
   /**
    * \returns the unique id of this node.
    * 
    * This unique id happens to be also the index of the INode into
    * the NodeList. 
    */
   uint32_t GetId (void) const;
@@ -87,7 +87,7 @@
 
   /**
    * \param device NetDevice to associate to this node.
    * \returns the index of the NetDevice into the INode's list of
    *          NetDevice.
    *
    * Associate this device to this node.
@@ -97,21 +97,21 @@
   uint32_t AddDevice (Ptr<NetDevice> device);
   /**
    * \param index the index of the requested NetDevice
    * \returns the requested NetDevice associated to this INode.
    */
   Ptr<NetDevice> GetDevice (uint32_t index) const;
   /**
    * \returns the number of NetDevice instances associated
-   *          to this INode.
+   *          to this Node.
    */
   uint32_t GetNDevices (void) const;
 
   /**
    * \param application Application to associate to this node.
    * \returns the index of the Application within the INode's list
    *          of Application.
    *
    * Associated this Application to this INode. This method is called
    * automatically from Application::Application so the user
    * has little reasons to call this method directly.
    */
@@ -119,11 +119,11 @@
   /**
    * \param index
    * \returns the application associated to this requested index
    *          within this INode.
    */
   Ptr<Application> GetApplication (uint32_t index) const;
   /**
    * \returns the number of applications associated to this INode.
    */
   uint32_t GetNApplications (void) const;
 
@@ -131,16 +131,16 @@
   /**
    * Must be invoked by subclasses only.
    */
-  INode();
+  Node();
   /**
    * \param systemId a unique integer used for parallel simulations.
    *
    * Must be invoked by subclasses only.
    */
-  INode(uint32_t systemId);
+  Node(uint32_t systemId);
   /**
    * The dispose method. Subclasses must override this method
    * and must chain up to it by calling INode::DoDispose at the
    * end of their own DoDispose method.
    */
   virtual void DoDispose (void);
@@ -153,16 +153,16 @@
    */
   virtual TraceResolver *DoCreateTraceResolver (TraceContext const &context) = 0;
   /**
    * \param device the device added to this INode.
    *
    * This method is invoked whenever a user calls INode::AddDevice.
    * Subclasses are expected to call NetDevice::SetReceiveCallback
    * at this point to setup the node's receive function for
    * the NetDevice packets.
    */
   virtual void DoAddDevice (Ptr<NetDevice> device) const = 0;
 
-  uint32_t    m_id;         // INode id for this node
+  uint32_t    m_id;         // Node id for this node
   uint32_t    m_sid;        // System id for this node
   std::vector<Ptr<NetDevice> > m_devices;
   std::vector<Ptr<Application> > m_applications;
@@ -19,7 +19,7 @@
 //
 
-// Define the basic INode object for ns3.
+// Define the basic Node object for ns3.
 // George F. Riley, Georgia Tech, Fall 2006
 
@@ -37,35 +37,35 @@
  *     Channel instances.
  *   - a list of Application objects which represent the userspace
- *     traffic generation applications which interact with the INode
+ *     traffic generation applications which interact with the Node
  *     through the Socket API.
  *   - a node Id: a unique per-node identifier.
@@ -37,35 +37,35 @@
    *          ownership of the returned pointer.
    *
-   * Request the INode to create a trace resolver. This method
+   * Request the Node to create a trace resolver. This method
    * could be used directly by a user who needs access to very low-level
    * trace configuration.
@@ -74,7 +74,7 @@
    * \returns the unique id of this node.
    * 
-   * This unique id happens to be also the index of the INode into
+   * This unique id happens to be also the index of the Node into
    * the NodeList. 
    */
@@ -87,7 +87,7 @@
   /**
    * \param device NetDevice to associate to this node.
-   * \returns the index of the NetDevice into the INode's list of
+   * \returns the index of the NetDevice into the Node's list of
    *          NetDevice.
    *
@@ -97,21 +97,21 @@
   /**
    * \param index the index of the requested NetDevice
-   * \returns the requested NetDevice associated to this INode.
+   * \returns the requested NetDevice associated to this Node.
    */
   Ptr<NetDevice> GetDevice (uint32_t index) const;
@@ -97,21 +97,21 @@
   /**
    * \param application Application to associate to this node.
-   * \returns the index of the Application within the INode's list
+   * \returns the index of the Application within the Node's list
    *          of Application.
    *
@@ -97,21 +97,21 @@
    *          of Application.
    *
-   * Associated this Application to this INode. This method is called
+   * Associated this Application to this Node. This method is called
    * automatically from Application::Application so the user
    * has little reasons to call this method directly.
@@ -119,11 +119,11 @@
    * \param index
    * \returns the application associated to this requested index
-   *          within this INode.
+   *          within this Node.
    */
   Ptr<Application> GetApplication (uint32_t index) const;
@@ -119,11 +119,11 @@
   Ptr<Application> GetApplication (uint32_t index) const;
   /**
-   * \returns the number of applications associated to this INode.
+   * \returns the number of applications associated to this Node.
    */
   uint32_t GetNApplications (void) const;
@@ -131,16 +131,16 @@
   /**
    * The dispose method. Subclasses must override this method
-   * and must chain up to it by calling INode::DoDispose at the
+   * and must chain up to it by calling Node::DoDispose at the
    * end of their own DoDispose method.
    */
@@ -153,16 +153,16 @@
   virtual TraceResolver *DoCreateTraceResolver (TraceContext const &context) = 0;
   /**
-   * \param device the device added to this INode.
+   * \param device the device added to this Node.
    *
@@ -153,16 +153,16 @@
    *
-   * This method is invoked whenever a user calls INode::AddDevice.
+   * This method is invoked whenever a user calls Node::AddDevice.
    * Subclasses are expected to call NetDevice::SetReceiveCallback
    * at this point to setup the node's receive function for